File

Struct File 

pub struct File<T, F>
where T: Merge,
{ /* private fields */ }
Available on crate feature file only.
The File evaluator.

An Evaluator accompanied by its driving logic. If you are trying to use this crate, this is probably where you should be looking.

Example

#[derive(Debug, PartialEq, Eq, serde::Deserialize, module::Merge)]
struct MyModule {
    a: Option<i32>,
    b: Option<Vec<usize>>,
}

let mut file: File<MyModule, format::Json> = File::default();

file.read(PathBuf::from("./module1.json")).unwrap();
file.read(PathBuf::from("./module2.json")).unwrap();

assert_eq!(file.finish(), Some(MyModule {
    a: Some(42),
    b: Some(vec![0, 1, 2, 3])
}));

Implementations

Source

impl<T, F> File<T, F>
where T: Merge,

pub fn new(format: F) -> Self

Create a new File evaluator that reads modules based on format.

See: Format.

Source

impl<T, F> File<T, F>
where T: Merge, F: Format<T>, F::Error: Send + Sync,

pub fn read(&mut self, path: PathBuf) -> Result<(), Error>

Read the module from the file at path.

This method will evaluate path along with all of its imports. It should be used to declare only the root of the module tree.

Example

See: File.

pub fn finish(self) -> Option<T>

Destruct the evaluator and get the final value.

Example

See: File.